@@ -4,6 +4,7 @@
 __all__ = ('PGPError',
            'PGPEncryptionError',
            'PGPDecryptionError',
+           'PGPIncompatibleECPointFormat',
            'PGPOpenSSLCipherNotSupported',
            'PGPInsecureCipher',
            'WontImplementError',)
@@ -24,6 +25,11 @@ class PGPDecryptionError(Exception):
     pass
 
 
+class PGPIncompatibleECPointFormat(Exception):
+    """Raised when the point format is incompatible with the elliptic curve"""
+    pass
+
+
 class PGPOpenSSLCipherNotSupported(Exception):
     """Raised when OpenSSL does not support the requested cipher"""
     pass
