@@ -1018,7 +1018,8 @@ class String2Key(Field):
 
         # Simple S2K - always done
         hsalt = b''
-        hpass = passphrase.encode('latin-1')
+        ##TODO: we could accept a passphrase that is optionally already `bytes`
+        hpass = passphrase.encode('utf-8')
 
         # salted, iterated S2K
         if self.specifier >= String2KeyType.Salted:
